/**
 *
 * Licensed Materials - Property of IBM
 * 
 * "Restricted Materials of IBM"
 * 
 * 5724-DST
 * 
 * (C) Copyright IBM Corp. 2007, 2008 All Rights Reserved.
 * 
 * US Government Users Restricted Rights - Use, duplication or  disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 *
 */

if(typeof dtconsole == "undefined"){ 
    // summary: namespace for data tools console
	var dtconsole = {}; 
};

(function(){
    dtconsole.version = {
        major: 1, minor: 2, patch: 0,
		toString: function(){
		    return this.major + "." + this.minor + "." + this.patch;
		}        
    };
    if(typeof dtconfig == "undefined"){
        // summary: 
        //     namespace for data tools console configuration property.
        //     can add more property in the dtconfig mixin.
        dtconfig = {};
    }
    var date = new Date();
    var isDaySavingTime = function(){
        // summary: function to detect is the browser side in daysaving time.
    	date.setMonth(0);
    	var diff1 = (date.getHours()-date.getUTCHours());
    	date.setMonth(4);
    	var diff2 = (date.getHours()-date.getUTCHours());
    	date.setMonth(8);
    	var diff3 = (date.getHours()-date.getUTCHours());
    	if( diff1 != diff2 || diff1 != diff3 || diff2 != diff3 ){
    		return true;
    	}
    	return false;        
    };
    dojo.mixin(dtconfig,{
        // summary: client time zone offline, such as -480 minutes for china;
        CLIENT_TIMEZONE_OFFSET: date.getTimezoneOffset(),
        // summary: The format of the Date and Time, YYYY-MM-DD HH:MM:SS;
        DATETIME_FORMAT: "%Y-%m-%d %T",
        // summary: The format of the Date only, YYYY-MM-DD;
        DATE_FORMAT: "%Y-%m-%d", 
        // summary: The format of the Time only, HH:MM:SS;
        TIME_FORMAT: "%T", 
        // summary: The short format of the Time only, HH:MM   
        SHORT_TIME_FORMAT: "%R",
        // summary: client time zone is DaySaving Time.
        IS_DAYSAVING_TIME: isDaySavingTime(),
        // summary: default delay timeout milliseconds to prevent the duplicate request;
        REQUEST_DELAY_MSEL: 300,
        // summary: default timeout milliseconds for the xmlhttprequest;
        XHR_TIMEOUT_SECONDS: 60000,
        // summary: default timeout seconds for the jsonrpc;
        RPC_TIMEOUT_SHORTSECONDS: 60, 
        // summary: Long timeout seconds for the jsonrpc;
        RPC_TIMEOUT_LONGSECONDS: 90,        
         // summary: default height of tabcontainer;
        MAIN_TABCONTAINER_HEIGHT: "550px"
    });
    
    dtconsole.ErrorObject = function(/*String*/message,
                                        /*String?*/name,
                                        /*String?|Object?*/extra){
        // summary: 
        //     The Object for bussiness logic exception.
        //     After throw the object, need be catch else will generate the [ uncaught exception: ...]
        //     Like the Error Object with the similar property and add an extra property to put the extra object information.  
        // message: text property for the object.
        // name: name of object, use to identify the error, default to dtconsole.util.ErrorObject.
        // extra: extra property for identify the object
            this.message = message;
            this.name = name||"dtconsole.ErrorObject";
            this.extra = extra;
            this.toString = function(){
                 var str = "[message]: " + this.message + "[name]: "
                      + this.name;
                 if(this.extra){
                     str = str + "[extra]: " + this.extra;
                 }
                 return str;
            };
    };
    
    var _dt = dtconsole;
	var _browserEnvObj = function(){
		var _browserEnv = {};
		var nav = navigator;
		for(var prop in nav){
			var obj = nav[prop];
			if(typeof obj == "string" || typeof obj == "boolean"){
				if(obj.length > 0){
					_browserEnv[prop] = obj;
				}
			}
		};
		_browserEnv["sceenHeight"] = window.screen.height;
		_browserEnv["sceenWidth"] = window.screen.width;
		return dojo.toJson(_browserEnv);	
	}
	_dt.browserEnv = _browserEnvObj();
    
    _dt.loggerClientException = function(logContent, callerFun ,isSendLog){
        var loggerStr = logContent + "\r\n" +" Browser Varaibles:" + _dt.browserEnv;
        if(callerFun != null){
            loggerStr += "\r\n" +"Invoke Function: "+ callerFun.toString();
        };
        if(typeof isSendLog == "undefined"){
            isSendLog = true;
        }
        if(isSendLog){
            var loggerXHR = dojo.xhrPost({
                url: dtconfig.contextPath + "/consolemessenger/clientLogHandler.ax",
                content: {logContent: loggerStr},
                timeout: 2000, 
                load: function(response,ioArgs){},
                error: function(response,ioArgs){return}
            });
        }
    } 		
    _dt.debug = console.debug;
    _dt.info = console.info;
    _dt.warn = console.warn;
    _dt.error = function(errorContent, isSendLog){
        var callerFun = arguments.callee.caller;
        console.error.apply(this,arguments);
        dtconsole.loggerClientException(errorContent,callerFun,isSendLog);
    };
    _dt.errorIntercept = function(/*String*/message,/*Strubg*/url,/*Number*/lineNo){
        // summary: 
        //     this function will be set to window.onerror event and catch all the exception that 
        //     hasn't been catch or handle by browser.
        // message: the Exception/Error message throw by browser.
        // url: the url link of current page throw exception
        // lineNo: the line number of the exception be throwed.
        var str = "[message]: " + message +" [url]: " + url + " [lineNo]: " + lineNo;
        var callerFun = arguments.callee.caller;
        dtconsole.loggerClientException(str, callerFun);
        //alert("Uncatch exception throw. callerFun:" + callerFun.toString());
        //FIXME: How do we deal with the exception, let it go on throw or just return?
        return false;
    };
})();

dojo.declare("dtconsole.Error",Error,{
    // summary: 
    //     The Object extend from JavaScript's Error Object,
    //     Like the Error Object with the similar property and add an extra property to put the extra object information. 
    //     Name property is 'Error'
    // message: Error Object message property.
	constructor: function(/*String*/message, /*String?|Object?*/extra){
		this.message = message;
		this.extra = extra;
		this.stack = (new Error()).stack;	
	},
    toString: function(){
         var str = "[message]: " + this.message + "[name]: "
              + this.name;
         if(this.extra){
             str = str + "[extra]: " + this.extra;
         };
         str = str + this.stack;
         return str;	        
    }
});
// Global intercept for the error hasn't been catched
window.onerror = dtconsole.errorIntercept;
dojo.addOnLoad(function(){
	// set the classes for dijit
    var theme  = djConfig.defaultTheme || 'sky'; 
	if(!dojo.hasClass(dojo.body(),theme)){ dojo.addClass(dojo.body(),theme); }	
});


